# ebookwords

## Architecture

```mermaid
graph LR
  config[config]
  subgraph interface[interface]
      webapp[webapp]
  end
  subgraph core[core]
      manager[book_manager]
  end
  subgraph adapter[adapter]
      parser[book_parser]
      extractor[book_extractor]
      db[db]
  end

  webapp --> config
  webapp --> manager

  manager --- split[ ]:::empty
  split --> parser
  split --> extractor
  split --> db

  classDef empty width:0px,height:0px;
```
